@@ -7,7 +7,7 @@ __all__ = [
     'to_absolute', 'to_relative',
     'enlarge_bbs', 'shrink_bbs',
     'logger', 'np', 'now','nunique','os','pad','pd','pdfilter','pdb',
-    'plt','PIL','puttext','randint','rand','re','read','readPIL','rect','rename_batch','resize','rotate','see',
+    'plt','PIL','puttext','randint','rand','re','read','readPIL','rect','resize','rotate','see',
     'set_logging_level','show','store_attr','subplots','sys','tqdm','Tqdm','trange','Timer','unique','uint','write',
     'BB','bbfy','xywh2xyXY','df2bbs',
     'Info','Warn','Debug','Excep','reset_logger_width',
@@ -15,6 +15,7 @@ __all__ = [
 ]
 
 from .logger import *
+from pathlib import Path
 from fastcore.foundation import L
 import glob, numpy as np, pandas as pd, tqdm, os, sys, re
 from IPython.display import display
@@ -168,24 +169,6 @@ def C(im):
     else:
         return np.repeat(im[...,None], 3, 2)
 
-def rename_batch(folder, func, debug=False, one_file=False):
-    'V.V.Imp: Use debug=True first to confirm file name changes are as expected'
-    if isinstance(folder, str): folder = Glob(folder)
-    sources = []
-    destins = []
-    log_file = f'moved_files_{now()}.log'
-    for f in folder:
-        source = f
-        destin = func(f)
-        if source == destin: continue
-        if debug:
-            logger.debug(f'moving `{source}` --> `{destin}`')
-        else:
-            # !mv {source.replace(' ','\ ')} {destin.replace(' ','\ ')}
-            logger.info(f'moving `{source}` --> `{destin}`')
-            os.rename(source, destin)
-        # !echo {source.replace(' ','\ ')} --\> {destin.replace(' ','\ ')} >> {logfile}
-        if one_file: break
 
 def common(a, b):
     """Wrapper around set intersection"""
@@ -220,7 +203,8 @@ def show(img=None, ax=None, title=None, sz=None, bbs=None, confs=None,
         if isinstance(img, (str, Path)): img = read(str(img), 1)
         if isinstance(img, torch.Tensor): img = img.cpu().detach().numpy().copy()
         if isinstance(img, PIL.Image.Image): img = np.array(img)
-    except: ...
+    except Exception as e:
+        print(e)
     if not isinstance(img, np.ndarray):
         display(img)
         return
